@@ -114,7 +114,6 @@ static void handle_sig(int dummy)
  */
 void health_check_exit(const int status)
 {
-	event_stop();
 	exit(status);
 }
 
@@ -576,9 +575,6 @@ int main(int argc, char **argv)
 	syscall_trace_proc(&pids);
 #endif
 	mem_init();
-#if EVENT_SUPPORTED
-	event_init();
-#endif
 	cpustat_init();
 	ctxt_switch_init();
 
@@ -588,10 +584,6 @@ int main(int argc, char **argv)
 	gettimeofday(&tv_start, NULL);
 	tv_end = timeval_add(&tv_start, &duration);
 
-#if EVENT_SUPPORTED
-	if (event_get_all_pids(&pids, PROC_START) < 0)
-		goto out;
-#endif
 	if (cpustat_get_all_pids(&pids, PROC_START) < 0)
 		goto out;
 	if (mem_get_all_pids(&pids, PROC_START) < 0)
@@ -655,19 +647,12 @@ int main(int argc, char **argv)
 	duration = timeval_sub(&tv_now, &tv_start);
 	actual_duration = timeval_to_double(&duration);
 
-#if EVENT_SUPPORTED
-	if (event_get_all_pids(&pids, PROC_FINISH) < 0)
-		goto out;
-#endif
 	if (cpustat_get_all_pids(&pids, PROC_FINISH) < 0)
 		goto out;
 	if (mem_get_all_pids(&pids, PROC_FINISH) < 0)
 		goto out;
 	if (ctxt_switch_get_all_pids(&pids, PROC_FINISH) < 0)
 		goto out;
-#if EVENT_SUPPORTED
-	event_stop();
-#endif
 #if SYSCALL_SUPPORTED
 	if (syscall_stop() < 0)
 		goto out;
@@ -680,9 +665,6 @@ int main(int argc, char **argv)
 
 	cpustat_dump_diff(json_tests, actual_duration);
 	pagefault_dump_diff(json_tests, actual_duration);
-#if EVENT_SUPPORTED
-	event_dump_diff(json_tests, actual_duration);
-#endif
 	ctxt_switch_dump_diff(json_tests, actual_duration);
 #if FNOTIFY_SUPPORTED
 	fnotify_dump_events(json_tests, actual_duration, &pids);
@@ -725,9 +707,6 @@ out:
 	net_connection_cleanup();
 #if SYSCALL_SUPPORTED
 	syscall_cleanup();
-#endif
-#if EVENT_SUPPORTED
-	event_cleanup();
 #endif
 	cpustat_cleanup();
 	ctxt_switch_cleanup();
